==> ejc-procurement-impl-3.0.0-20251212.085946-107-sources.jar: com/ejianc/business/procurement/perform/bean/PurchaseProjectMemberEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 采购项目-采购小组成员名单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_project_member")
public class PurchaseProjectMemberEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="leader_flag")
    private Integer leaderFlag; // 是否组长
    @TableField(value="member_type")
    private String memberType; // 类型
    @TableField(value="member_name")
    private String memberName; // 供应商名称
    @TableField(value="member_code")
    private String memberCode; // 供应商编码
    @TableField(value="member_id")
    private Long memberId; // 供应商id
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getLeaderFlag() {
        return leaderFlag;
    }

    public void setLeaderFlag(Integer leaderFlag) {
        this.leaderFlag = leaderFlag;
    }
    public String getMemberType() {
        return memberType;
    }

    public void setMemberType(String memberType) {
        this.memberType = memberType;
    }
    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }
    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }
    public Long getMemberId() {
        return memberId;
    }

    public void setMemberId(Long memberId) {
        this.memberId = memberId;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251215.081812-122-sources.jar: com/ejianc/business/procurement/perform/bean/PurchaseProjectMemberEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 采购项目-采购小组成员名单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_purchase_project_member")
public class PurchaseProjectMemberEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="leader_flag")
    private Integer leaderFlag; // 是否组长
    @TableField(value="member_type")
    private String memberType; // 类型
    @TableField(value="member_name")
    private String memberName; // 员工名称
    @TableField(value="member_code")
    private String memberCode; // 员工编码
    @TableField(value="member_id")
    private Long memberId; // 员工id
    
    
    

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getLeaderFlag() {
        return leaderFlag;
    }

    public void setLeaderFlag(Integer leaderFlag) {
        this.leaderFlag = leaderFlag;
    }
    public String getMemberType() {
        return memberType;
    }

    public void setMemberType(String memberType) {
        this.memberType = memberType;
    }
    public String getMemberName() {
        return memberName;
    }

    public void setMemberName(String memberName) {
        this.memberName = memberName;
    }
    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }
    public Long getMemberId() {
        return memberId;
    }

    public void setMemberId(Long memberId) {
        this.memberId = memberId;
    }
    
}
